@@ -3,7 +3,6 @@ use warnings;
 
 package # hide from PAUSE
     DBIx::DBO::Common::DBD::Oracle;
-use DBIx::DBO::Common;
 
 sub _build_limit {
     '';
@@ -27,11 +26,11 @@ sub _alias_preference {
 
 package # hide from PAUSE
     DBIx::DBO::Query::DBD::Oracle;
-use DBIx::DBO::Common;
+use Carp 'croak';
 
 sub limit {
     my $me = shift;
-    ouch "The LIMIT clause with an OFFSET is not supported by Oracle" if @_ > 1;
+    croak "The LIMIT clause with an OFFSET is not supported by Oracle" if @_ > 1;
     $me->SUPER::limit(@_);
 }
 
