@@ -80,6 +80,7 @@ sub table_info {
 
 package # hide from PAUSE
     DBIx::DBO::Table::DBD::Pg;
+use Carp 'croak';
 
 sub _save_last_insert_id {
     my $me = shift;
@@ -87,4 +88,8 @@ sub _save_last_insert_id {
     return $sth->{Database}->last_insert_id(undef, @$me{qw(Schema Name)}, undef);
 }
 
+sub _do_bulk_insert {
+    shift->_fast_bulk_insert(@_);
+}
+
 1;
